package de.hhu.ba.yoshikoWrapper.core;

import java.util.List;

import org.cytoscape.model.CyColumn;
import org.cytoscape.model.CyEdge;
import org.cytoscape.model.CyNetwork;
import org.cytoscape.model.CyRow;
import org.slf4j.Logger;

import de.hhu.ba.yoshikoWrapper.logging.YoshikoLogger;
import de.hhu.ba.yoshikoWrapper.swig.LibraryInterface;
import de.hhu.ba.yoshikoWrapper.swig.SWIGTYPE_p_yskInput__LibraryInput;

public class NetworkParser {
	
	//Symbolic Links
	private static Logger logger = YoshikoLogger.getInstance().getLogger();

	public static SWIGTYPE_p_yskInput__LibraryInput parseNetwork(
			CyNetwork net,
			NodeMap nodeMap,
			CyColumn weightColumn,
			double deletionCostDefault
			) 
	{
		//Create an empty instance / fetch C++ object pointer
		SWIGTYPE_p_yskInput__LibraryInput generatedInput = LibraryInterface.new_LibraryInput();
		if (net != null){
			//Create an empty full graph with a given size
			LibraryInterface.LibraryInput_setSize(generatedInput,  net.getNodeCount());
			//Fetch edges
			List<CyEdge> edges = net.getEdgeList();
			

			
			//Loop over edges
			for (CyEdge e : edges) {
				CyRow edgeEntry = net.getRow(e);
				//Set to default cost
				double weight = deletionCostDefault;
				if (weightColumn != null){
					try {
						//Find out if the weights are double or int
						@SuppressWarnings("unchecked")
						Class<? extends Number> weightType = (Class<? extends Number>) weightColumn.getType();
						logger.info("Column has type: "+weightType.getName());
						weight = (double)edgeEntry.get(weightColumn.getName(), weightType);
					}
					catch(Exception ex) {
						//Invalid entry (no entry)
						logger.info("No valid edit costs defined for: "+edgeEntry.get("name", String.class)+", falling back to default value!");
					}
				}


				logger.debug("Found Edge: "+edgeEntry.get("name", String.class)+ " with weight:"+weight);
				
				LibraryInterface.LibraryInput_addEdge(generatedInput,
						nodeMap.get(e.getSource()),
						nodeMap.get(e.getTarget())
						, weight);
				
			}
		}
		return generatedInput;
	}



	


}
